/*======================================================*/
/*  Cards.cpp  -  a tiny deck of cards example          */
/*                to illustrate STRUCT                  */
/*======================================================*/

#include <iostream.h>
#include <iomanip.h>

enum VALUE { V2=2, V3, V4, V5, V6, V7, V8, V9, 
             V10, JACK, QUEEN, KING, ACE
           };
enum SUIT { CLUB, DIAMOND, HEART, SPADE };

struct CARD        // contains one "card"
{
    VALUE value;   // e.g., 2 or Ace...
    SUIT  suit;    // e.g., club or spade...
};

typedef CARD DECK [52]; // a deck of cards

void InitializeDeck (DECK deck)
{
    VALUE eValue;
    SUIT  eSuit;
    int   nCardNo = 0;

    for (eSuit = CLUB; eSuit <= SPADE; eSuit = SUIT (eSuit+1))
        for (eValue = V2; eValue <= ACE; eValue = VALUE (eValue+1))
        {
            deck [nCardNo] . suit  = eSuit;
            deck [nCardNo] . value = eValue;
            nCardNo++;
        }
}

void PrintCard (CARD card)
{
    switch (card.suit)
    {
    case CLUB:       cout << "Club-";     break;
    case DIAMOND:    cout << "Diamond-";  break;
    case HEART:      cout << "Heart-";    break;
    case SPADE:      cout << "Spade-";    break;
    }
    if (card.value < JACK)
        cout << int (card.value) << " ";
    else
        cout << ((card.value == JACK)  ? "J " :
                 (card.value == QUEEN) ? "Q " :
                 (card.value == KING)  ? "K " :
                 (card.value == ACE)   ? "A " : 
                                         "? ");
}

void PrintDeck (DECK deck)
{
    for (int i = 0; i < 52; i++)
    {
        cout << setw (3) << (i + 1) << "  ";
        PrintCard (deck [i]);
        cout << endl;
    }
}

int main (void)
{
    CARD aceOfSpades = { ACE, SPADE };
    DECK deck;

    PrintCard (aceOfSpades);
    InitializeDeck (deck);
    PrintDeck (deck);

    return 0;
}

/*======================================================*/

/*----------------------
Output from the program:

Spade-A
  1  Club-2 
  2  Club-3 
  3  Club-4 
  4  Club-5 
  5  Club-6 
  6  Club-7 
  7  Club-8 
  8  Club-9 
  9  Club-10 
 10  Club-J 
 11  Club-Q 
 12  Club-K 
 13  Club-A 
 14  Diamond-2 
 15  Diamond-3 
 16  Diamond-4 
 17  Diamond-5 
 18  Diamond-6 
 19  Diamond-7 
 20  Diamond-8 
 21  Diamond-9 
 22  Diamond-10 
 23  Diamond-J 
 24  Diamond-Q 
 25  Diamond-K 
 26  Diamond-A 
 27  Heart-2 
 28  Heart-3 
 29  Heart-4 
 30  Heart-5 
 31  Heart-6 
 32  Heart-7 
 33  Heart-8 
 34  Heart-9 
 35  Heart-10 
 36  Heart-J 
 37  Heart-Q 
 38  Heart-K 
 39  Heart-A 
 40  Spade-2 
 41  Spade-3 
 42  Spade-4 
 43  Spade-5 
 44  Spade-6 
 45  Spade-7 
 46  Spade-8 
 47  Spade-9 
 48  Spade-10 
 49  Spade-J 
 50  Spade-Q 
 51  Spade-K 
 52  Spade-A 

------------------------*/
